@@ -1,7 +1,3 @@
-##' @useDynLib jqr
-##' @importFrom Rcpp evalCpp
-NULL
-
 cpt <- function(l) Filter(Negate(is.null), l)
 
 comb <- function(x, y) {
